@@ -1,5 +1,6 @@
 use cosmwasm_std::{
     to_binary,
+    Addr,
     QuerierWrapper,
     QueryRequest,
     StdResult,
@@ -35,12 +36,12 @@ pub struct PriceFeedResponse {
 /// Queries the price on-chain
 pub fn query_price_feed(
     querier: &QuerierWrapper,
-    contract_addr: String,
+    contract_addr: Addr,
     id: PriceIdentifier,
 ) -> StdResult<PriceFeedResponse> {
     let price_feed_response = querier.query(&QueryRequest::Wasm(WasmQuery::Smart {
-        contract_addr,
-        msg: to_binary(&QueryMsg::PriceFeed { id })?,
+        contract_addr: contract_addr.into_string(),
+        msg:           to_binary(&QueryMsg::PriceFeed { id })?,
     }))?;
     Ok(price_feed_response)
 }
